@@ -172,7 +172,7 @@ void CDraftFrame::OnSend()
 	this->m_me.SetFrom(m_pAddrsV->GetFrom());
 	this->m_me.SetSubject(m_pAddrsV->GetSubject());
 	this->m_me.SetReplyTo(m_pAddrsV->GetReplyTo());
-	this->m_me.SetXMailer(X_MAILER);
+	this->m_me.SetXMailer(app->GetProfileString("Customize", "XMailer", X_MAILER));
 	// 12 Apr 2003 15:40:48 +0900
 	CTime time = CTime::GetCurrentTime();
 	this->m_me.SetDate(time.Format("%d %b %Y %H:%M:%S ")+DEF_TIME_ZONE);
