@@ -182,7 +182,7 @@ void CMailEditView::OnInitialUpdate()
 
 
 	// sԂ𒲐
-	PARAFORMAT2 pf;
+/*	PARAFORMAT2 pf;
 	pf.cbSize = sizeof(pf);
 	pf.dwMask = PFM_LINESPACING | PFM_SPACEAFTER;
 	pf.dySpaceAfter = 0;
@@ -190,7 +190,7 @@ void CMailEditView::OnInitialUpdate()
 	pf.dyLineSpacing = 280;
 	r.SetSel(0,-1);
 	r.SendMessage(EM_SETPARAFORMAT,0,(LPARAM)&pf);
-	r.SetSel(0,0);
+	r.SetSel(0,0);*/
 
 	// {ݒ
 	CDraftFrame* df = (CDraftFrame*)GetParentFrame();
@@ -213,11 +213,6 @@ void CMailEditView::OnInitialUpdate()
 	m_nWordWrap = WrapNone;
 	WrapChanged(); // ܂ԂȂ
 	r.SetOptions(ECOOP_OR,ECO_AUTOHSCROLL);
-
-	CRect rect1;
-	this->GetWindowRect(rect1);
-	rect1.right += 500;
-	r.SetRect(rect1);
 }
 
 void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
@@ -512,7 +507,7 @@ void CMailEditView::OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult )
 			// {ݒ
 			app->m_me.AddText(signature);
 			// draftframe
-			app->CreateDraftFrame();
+			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 		}
 		else
 			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_SHOWNORMAL);
