@@ -795,11 +795,14 @@ void CMainFrame::OnReplyQuotation()
 	reply_to.ReleaseBuffer();
 	app->m_me.SetReplyTo(reply_to);
 
-	// message-id̐ݒ
+	// message-id
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
-	// In-reply-to̐ݒ
+	// In-reply-to
 	app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
+	// setting references
+	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
+
 
 	// {Ɉpݒ
 	CString body = m_pTextV->GetCurrentBody();
@@ -861,13 +864,15 @@ void CMainFrame::OnReplyNoQuotation()
 	reply_to.ReleaseBuffer();
 	app->m_me.SetReplyTo(reply_to);
 
-	// message-id̐ݒ
+	// setting message-id
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
-	// In-reply-to̐ݒ
+	// setting in-reply-to
 	app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
+	// setting references
+	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
 
-	// Subject̐ݒ
+	// setting subject
 	if(m_pTextV->GetCurrentSubject().Find("Re:") == 0)
 		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
 	else if(m_pTextV->GetCurrentSubject().Find("RE:") == 0)
@@ -878,7 +883,7 @@ void CMainFrame::OnReplyNoQuotation()
 	CString signature;
 	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
 
-	// {ݒ
+	// setting body
 	MULTIPART_STRUCT2 data;
 	data.m_body = signature;
 	data.m_type = "Text/Plain; charset=ISO-2022-JP";
