@@ -13,6 +13,7 @@
 #include "base64.h"
 #include "CodeConvert.h"
 #include "lib.h"
+#include "process.h" // getpid()
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -71,6 +72,7 @@ void CMimeEncode::CopyFrom(CMimeEncode *me)
 	m_data.m_in_reply_to = me->m_data.m_in_reply_to;
 	m_data.m_message_id = me->m_data.m_message_id;
 	m_data.m_reply_to = me->m_data.m_reply_to;
+	m_data.m_references = me->m_data.m_references;
 	m_data.m_subject = me->m_data.m_subject;
 	m_data.m_to = me->m_data.m_to;
 	m_mime_mode = me->m_mime_mode;
@@ -113,6 +115,11 @@ CString CMimeEncode::GetInReplyTo()
 	return m_data.m_in_reply_to;
 }
 
+CString CMimeEncode::GetReferences()
+{
+	return m_data.m_references;
+}
+
 CString CMimeEncode::GetSubject()
 {
 	return m_data.m_subject;
@@ -127,6 +134,7 @@ CString CMimeEncode::GetMail(int for_what)
 {
 	CString header;
 	CString mail;
+	CString boundary;
 
 	// wb_̍\
 	// RFC 822 	To: Pooh Lovers:pooh@100acre.woodwest.uk,piglet@beech.tree.uk; not yet.
@@ -138,6 +146,8 @@ CString CMimeEncode::GetMail(int for_what)
 			header += "Cc: "+GetCc()+"\r\n";
 		if(!GetInReplyTo().IsEmpty())
 			header += "In-reply-to: "+GetInReplyTo()+"\r\n";
+		if(!GetReferences().IsEmpty())
+			header += "References: "+GetReferences()+"\r\n";
 		if(!GetReplyTo().IsEmpty())
 			header += "Reply-To: "+GetReplyTo()+"\r\n";
 		if((for_what == ME_GET_DRAFT || for_what == ME_GET_OUTBOX) && !GetBcc().IsEmpty())
@@ -183,21 +193,28 @@ CString CMimeEncode::GetMail(int for_what)
 		body = cc2.ToJis();
 		mail = header+"\r\n"+body;
 	}else{
+		boundary = this->GetBoundaryChar();
+		i = 0;
+		while(i < this->HowManyPart()){
+			while(this->GetBody(i).Find(boundary) != -1){
+				Sleep(10);
+				boundary = this->GetBoundaryChar();
+			}
+			i++;
+		}
 		if(m_mime_mode == ME_MODE_NONE){
-			header += "Content-Type: Multipart/Mixed; boundary=----kyoukaisen\r\n";
+			header += "Content-Type: Multipart/Mixed; boundary="+boundary+"\r\n";
 			header += "Content-Transfer-Encoding: 7bit\r\n";
-		}
-		else if(m_mime_mode == ME_MODE_PGP){
-			header += "Content-Type: Multipart/Encrypted; boundary=----kyoukaisen; protocol=application/pgp-encrypted\r\n";
+		}else if(m_mime_mode == ME_MODE_PGP){
+			header += "Content-Type: Multipart/Encrypted; boundary="+boundary+"; protocol=application/pgp-encrypted\r\n";
 			header += "Content-Transfer-Encoding: 7bit\r\n";
-		}
-		else if(m_mime_mode == ME_MODE_RFC822){}
+		}else if(m_mime_mode == ME_MODE_RFC822){}
 		CCodeConvert cc(header);
 		header = cc.ToJis();
 		EncodeHeader(header);
 		i = 0;
-		while(i < HowManyPart()){
-			body += "------kyoukaisen\r\n";
+		while(i < this->HowManyPart()){
+			body += "--"+boundary+"\r\n";
 			if(!GetCT(i).IsEmpty()) body += GetCT(i)+"\r\n";
 			if(!GetCTE(i).IsEmpty()) body += GetCTE(i)+"\r\n";
 			if(!GetCD(i).IsEmpty()) body += GetCD(i)+"\r\n";
@@ -207,7 +224,7 @@ CString CMimeEncode::GetMail(int for_what)
 			body += "\r\n\r\n";
 			i++;
 		}
-		body += "------kyoukaisen--\r\n";
+		body += "--"+boundary+"--\r\n";
 		CCodeConvert cc2(body);
 		body = cc2.ToJis();
 		mail = header+"\r\n"+body;
@@ -280,6 +297,11 @@ void CMimeEncode::SetInReplyTo(CString in_reply_to)
 	m_data.m_in_reply_to = in_reply_to;
 }
 
+void CMimeEncode::SetReferences(CString references)
+{
+	m_data.m_references = references;
+}
+
 void CMimeEncode::SetDate(CString date)
 {
 	m_data.m_date = date;
@@ -589,3 +611,91 @@ BOOL CMimeEncode::EncodeBase64(CString &out, CString in)
 {
 	return TRUE;
 }
+
+CString CMimeEncode::GetBoundaryChar()
+{
+	CString boundary;
+	CString day_of_week;
+	CString month;
+//	enum {sun=1, man, tue, wed, thu, fri, sat};
+//	enum {jan=1, feb, mar, apr, may, jun, jul, aug, sep, oct, nov, dec};
+
+	CTime t = CTime::GetCurrentTime();
+
+	switch(t.GetDayOfWeek()){
+	case 1:
+		day_of_week = "Sun";
+		break;
+	case 2:
+		day_of_week = "Man";
+		break;
+	case 3:
+		day_of_week = "Tue";
+		break;
+	case 4:
+		day_of_week = "Wed";
+		break;
+	case 5:
+		day_of_week = "Thu";
+		break;
+	case 6:
+		day_of_week = "Fri";
+		break;
+	case 7:
+		day_of_week = "Sat";
+		break;
+
+	}
+
+	switch(t.GetMonth()){
+	case 1:
+		month = "Jan";
+		break;
+	case 2:
+		month = "Feb";
+		break;
+	case 3:
+		month = "Mar";
+		break;
+	case 4:
+		month = "Apr";
+		break;
+	case 5:
+		month = "May";
+		break;
+	case 6:
+		month = "Jun";
+		break;
+	case 7:
+		month = "Jul";
+		break;
+	case 8:
+		month = "Aug";
+		break;
+	case 9:
+		month = "Sep";
+		break;
+	case 10:
+		month = "Oct";
+		break;
+	case 11:
+		month = "Nov";
+		break;
+	case 12:
+		month = "Dec";
+		break;
+	}
+
+	boundary.Format("--Next_Part(%s_%s_%02d_%02d:%02d:%02d_%d_%d)-",
+		day_of_week,
+		month,
+		t.GetDay(),
+		t.GetHour(),
+		t.GetMinute(),
+		t.GetSecond(),
+		t.GetYear(),
+		getpid());
+
+	return boundary;
+
+}
