@@ -191,9 +191,12 @@
 #define IDC_SETTING_CHECK_APOP          1089
 #define IDC_SETTING_GENERAL_EDITVIEW_FONT_COLOR 1090
 #define IDC_ABOUTBOX_VERSION            1090
+#define IDC_SETTING_CHECK_SMTP_AUTH     1090
 #define IDC_SETTING_GENERAL_EDITVIEW_FONT_TYPE 1091
 #define IDC_APPABOUT_COPY               1091
 #define IDC_SETTING_DEF_ADDRESS_EDIT    1092
+#define IDC_SETTING_SMTP_AUTH_ID        1093
+#define IDC_SETTING_SMTP_AUTH_PASS      1094
 #define ID_DRAFT                        32771
 #define ID_FETCH_MAIL                   32773
 #define ID_SEND_MAIL                    32774
@@ -271,7 +274,7 @@
 #define _APS_3D_CONTROLS                     1
 #define _APS_NEXT_RESOURCE_VALUE        205
 #define _APS_NEXT_COMMAND_VALUE         32901
-#define _APS_NEXT_CONTROL_VALUE         1093
+#define _APS_NEXT_CONTROL_VALUE         1095
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
 #endif
