@@ -7,7 +7,8 @@
 #include "Pochy.h"
 #include "MainFrm.h"
 #include "DraftFrame.h"
-#include "Sock.h"
+//#include "Sock.h"
+#include "Smtp.h"
 #include "CodeConvert.h"
 #include "sendmail.h"
 #include "direct.h"
@@ -16,8 +17,8 @@
 #include "DraftSendDlg.h"
 
 #define send_command(mes) \
-		send(SmtpSocket.m_sock, command, command.GetLength(), 0);\
-		if(SmtpSocket.SockRead(buf) == -1)\
+		send(Smtp.m_sock, command, command.GetLength(), 0);\
+		if(Smtp.SockRead(buf) == -1)\
 			throw mes;\
 		if(buf.Find("250") != 0 && buf.Find("354") != 0 && buf.Find("221") != 0)\
 			throw buf.GetBuffer(0);\
@@ -28,11 +29,14 @@
 
 UINT SendMail(LPVOID pParam)
 {
-	CSock SmtpSocket;
+//	CSock SmtpSocket;
+	CSmtp Smtp;
 	CSock PopSocket;
 	CString smtp_ip;
   	CString smtp_addr;
 	CString smtp_port;
+	CString smtp_auth_id;
+	CString smtp_auth_pass;
 	CString buf;
 	CString command;
 	int left;
@@ -144,7 +148,7 @@ UINT SendMail(LPVOID pParam)
 		GetPrivateProfileString("smtp", "server_addr", "", smtp_addr.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 		GetPrivateProfileString("smtp", "port", "", smtp_port.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 
-		if(INVALID_SOCKET == SmtpSocket.Connect6(smtp_addr.GetBuffer(0), smtp_port.GetBuffer(0))){
+		if(INVALID_SOCKET == Smtp.Connect6(smtp_addr.GetBuffer(0), smtp_port.GetBuffer(0))){
 			throw "cannot establish connection";
 		}
 //============== ZbVJn ============
@@ -152,21 +156,32 @@ UINT SendMail(LPVOID pParam)
 		CTime t = CTime::GetCurrentTime();
 		date.Format("%02d/%02d/%d %02d:%02d:%02d",t.GetDay(),t.GetMonth(),t.GetYear(),t.GetHour(),t.GetMinute(),t.GetSecond());
 		g_log("log-sendmail", "------- "+ date +" -------\r\n");
-		if(SmtpSocket.SockRead(buf) == -1)
+		if(Smtp.SockRead(buf) == -1)
 			throw "in connection";
 		g_log("log-sendmail", buf);
 		df->m_send_dlg->m_status.SetWindowText(buf);
 		buf.Empty();
-	//-------------- helo ------------------
+/*	//-------------- helo ------------------
 		char tmpbuf[256];
 		gethostname(tmpbuf, 255);
 		CString hostname = tmpbuf;
 		if(hostname.IsEmpty())
 			hostname = "unknown";
 		command="helo "+hostname+"\r\n";
-		send_command("at HELO command");
+		send_command("at HELO command");*/
+		if(GetPrivateProfileInt("smtp", "auth", 0, path)){
+			GetPrivateProfileString("smtp", "auth_id", "", smtp_auth_id.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			smtp_auth_id.ReleaseBuffer();
+			GetPrivateProfileString("smtp", "auth_pass", "", smtp_auth_pass.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			smtp_auth_pass.ReleaseBuffer();
+			if(!Smtp.Ehlo(smtp_auth_id, smtp_auth_pass)){
+				throw "smtp auth error";
+			}
+		}else{
+			Smtp.Helo();
+		}
 	//-------------- mail from -------------
-		command = "mail from: "+g_cstr_chop2(g_ma(df->m_me.GetFrom()))+"\r\n";
+		command = "mail from: <"+g_cstr_chop2(g_ma(df->m_me.GetFrom()))+">\r\n";
 		send_command("at MAIL FROM command");
 	//-------------- rcpt ------------------
 		left = 0;
@@ -178,12 +193,12 @@ UINT SendMail(LPVOID pParam)
 		g_strip_part(to, "\""); // ""̕폜iRgɁA,Ƃ΂̂Łj
 		right = to.Find(",");
 		while(right != -1){
-			command = "rcpt to: "+g_cstr_chop2(g_ma(to.Mid(left, right-left)))+"\r\n";
+			command = "rcpt to: <"+g_cstr_chop2(g_ma(to.Mid(left, right-left)))+">\r\n";
 			send_command("at RCPT TO command");
 			left = right+1;
 			right = to.Find(",", left);
 		}
-		command = "rcpt to: "+g_cstr_chop2(g_ma(to.Mid(left,to.GetLength()-left)))+"\r\n";
+		command = "rcpt to: <"+g_cstr_chop2(g_ma(to.Mid(left,to.GetLength()-left)))+">\r\n";
 		send_command("at RCPT TO command");
 
 		//-------------- body ------------------
@@ -205,20 +220,20 @@ UINT SendMail(LPVOID pParam)
 		while(current_len < whole_len){
 			buf = mail.Left(part_len);
 			mail = mail.Mid(part_len);
-			send(SmtpSocket.m_sock, buf, buf.GetLength(), 0);
+			send(Smtp.m_sock, buf, buf.GetLength(), 0);
 			buf.Empty();
 			df->m_send_dlg->m_progress.SetPos(current_len);
 			current_len += part_len;
 		}
-		send(SmtpSocket.m_sock, mail, mail.GetLength(), 0);
+		send(Smtp.m_sock, mail, mail.GetLength(), 0);
 		df->m_send_dlg->m_progress.SetPos(whole_len);
 
-		send(SmtpSocket.m_sock, "\r\n.\r\n", strlen("\r\n.\r\n"), 0);
+		send(Smtp.m_sock, "\r\n.\r\n", strlen("\r\n.\r\n"), 0);
 
 		CSummaryView *sv = mf->m_pListV;
 		sv->SaveMail(path, df->m_me.GetMail(ME_GET_OUTBOX), SMRY_STATUS_NONE, SMRY_COLUMN_TO);
 
-		if(SmtpSocket.SockRead(buf) == -1)
+		if(Smtp.SockRead(buf) == -1)
 			throw "at BODY command";
 		g_log("log-sendmail", buf);
 		df->m_send_dlg->m_status.SetWindowText(buf);
@@ -228,12 +243,12 @@ UINT SendMail(LPVOID pParam)
 		command = "quit\r\n";
 		send_command("at QUIT command");
 		// socket
-		SmtpSocket.DisConnect();
+		Smtp.DisConnect();
 	}
 	catch(char* errorstr){
-		send(SmtpSocket.m_sock, "quit\r\n", 6, 0);
+		send(Smtp.m_sock, "quit\r\n", 6, 0);
 		// socket
-		SmtpSocket.DisConnect();
+		Smtp.DisConnect();
 		df->MessageBox(errorstr, df->m_account+" - smtp error");
 		df->EnableWindow(TRUE);
 		df->m_send_dlg->m_status.SetWindowText("");
