@@ -605,7 +605,10 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 		if(fv->GetSelectedItemKind() == FV_DRAFT){
 			CUIntArray ia;
 			this->GetSelectedMail(ia);
-			this->DeleteMail(ia);
+			CString message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ndraft폜Ă悢łH";
+			if(IDYES == AfxMessageBox(message, MB_YESNO)){
+				this->DeleteMail(ia);
+			}
 		}
 		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 	}
