@@ -425,7 +425,7 @@ typedef struct
    unfortunately clutters up the declarations a bit, but I think it's
    worth it.  */
 
-#if __STDC__
+#ifdef __STDC__
 
 #define _RE_ARGS(args) args
 
@@ -517,7 +517,9 @@ extern int regexec
 extern size_t regerror
   (int errcode, const regex_t *preg, char *errbuf,
              size_t errbuf_size);
-extern void regfree _RE_ARGS ((regex_t *preg));
+/* below is changed by hiranaka */
+//extern void regfree _RE_ARGS ((regex_t *preg));
+extern void regfree (regex_t *preg);
 
 
 #ifdef __cplusplus
