@@ -48,8 +48,8 @@
 #define DEF_BOXNAME_OUTBOX "Mς"
 #define DEF_BOXNAME_DRAFT "e"
 #define DEF_BOXNAME_TRASH "S~"
-#define X_MAILER "Pochy 0.1.3 (KrungThep) http://pochy.sourceforge.jp"
-#define VERSION "Pochy 0.1.3 (KrungThep)"
+#define X_MAILER "Pochy 0.1.4 (ChiangRai)"
+#define VERSION "Pochy 0.1.4 (ChiangRai)"
 #define COPYRIGHT "Copyright (C) 2003"
 #define DEF_TIME_ZONE "+0900"
 #define DEF_POP_PORT "110"
